@@ -44,9 +44,9 @@ base_params = {
     "dust": 1,
     "hrkey": 1,
     "zonmean": "off",
-    "var1": "mtot",
-    "var2": "t",
-    "var3": "p",
+    "var1": "none",
+    "var2": "none",
+    "var3": "none",
     "var4": "none",
     "dpi": 80,
     "islog": "off",
